@@ -8,7 +8,7 @@
 
 G_BEGIN_DECLS
 
-/* Enumerations from "ggit-types.h" */
+/* Enumerations from "./ggit-types.h" */
 
 #define GGIT_TYPE_BRANCH_TYPE	(ggit_branch_type_get_type())
 GType ggit_branch_type_get_type	(void) G_GNUC_CONST;
@@ -109,6 +109,12 @@ GType ggit_diff_find_flags_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_DIFF_FORMAT_EMAIL_FLAGS	(ggit_diff_format_email_flags_get_type())
 GType ggit_diff_format_email_flags_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_CREDTYPE	(ggit_credtype_get_type())
+GType ggit_credtype_get_type	(void) G_GNUC_CONST;
+
+#define GGIT_TYPE_DIRECTION	(ggit_direction_get_type())
+GType ggit_direction_get_type	(void) G_GNUC_CONST;
+
 G_END_DECLS
 
 #endif /* __GGIT_ENUM_TYPES_H__ */
