@@ -45,7 +45,7 @@ GgitIndexEntry   *ggit_index_entries_get_by_index     (GgitIndexEntries  *entrie
 
 GgitIndexEntry   *ggit_index_entries_get_by_path      (GgitIndexEntries *entries,
                                                        GFile            *file,
-                                                       gboolean          stage);
+                                                       gint              stage);
 
 guint             ggit_index_entries_size             (GgitIndexEntries  *entries);
 
@@ -98,6 +98,9 @@ gboolean          ggit_index_entry_stat               (GgitIndexEntry    *entry,
                                                        GFile             *file,
                                                        GError           **error);
 
+void              ggit_index_entry_set_commit         (GgitIndexEntry    *entry,
+                                                       GgitCommit        *commit);
+
 const git_index_entry
                  *_ggit_index_entry_get_native        (GgitIndexEntry    *entry);
 
