@@ -74,10 +74,53 @@ G_DEFINE_TYPE_EXTENDED (GgitRepository, ggit_repository, GGIT_TYPE_NATIVE,
                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                ggit_repository_initable_iface_init))
 
+static GHashTable *registry = NULL;
+
+static GgitRepository *
+repository_from_registry (git_repository *repository)
+{
+	if (registry == NULL)
+	{
+		return NULL;
+	}
+
+	return g_hash_table_lookup (registry, repository);
+}
+
+static void
+register_repository (git_repository *repository,
+                     GgitRepository *wrapper)
+{
+	if (registry == NULL)
+	{
+		registry = g_hash_table_new (g_direct_hash, g_direct_equal);
+	}
+
+	g_hash_table_insert (registry, repository, wrapper);
+}
+
+static void
+unregister_repository (git_repository *repository)
+{
+	if (registry == NULL)
+	{
+		return;
+	}
+
+	g_hash_table_remove (registry, repository);
+
+	if (g_hash_table_size (registry) == 0)
+	{
+		g_hash_table_destroy (registry);
+		registry = NULL;
+	}
+}
+
 static void
 ggit_repository_finalize (GObject *object)
 {
 	GgitRepositoryPrivate *priv = GGIT_REPOSITORY (object)->priv;
+	git_repository *repo;
 
 	g_free (priv->url);
 	g_clear_object (&priv->location);
@@ -88,6 +131,13 @@ ggit_repository_finalize (GObject *object)
 		ggit_clone_options_free (priv->clone_options);
 	}
 
+	repo = _ggit_native_get (object);
+
+	if (repo != NULL)
+	{
+		unregister_repository (repo);
+	}
+
 	G_OBJECT_CLASS (ggit_repository_parent_class)->finalize (object);
 }
 
@@ -391,16 +441,30 @@ _ggit_repository_wrap (git_repository *repository,
 {
 	GgitRepository *ret;
 
+	ret = repository_from_registry (repository);
+
+	if (ret != NULL)
+	{
+		return g_object_ref (ret);
+	}
+
 	ret = g_object_new (GGIT_TYPE_REPOSITORY,
 	                    "native", repository,
 	                    NULL);
 
+	ret->priv->workdir = ggit_repository_get_workdir (ret);
+
 	if (owned)
 	{
 		_ggit_native_set_destroy_func (ret,
 		                               (GDestroyNotify)git_repository_free);
 	}
 
+	if (owned)
+	{
+		register_repository (repository, ret);
+	}
+
 	return ret;
 }
 
@@ -622,14 +686,7 @@ ggit_repository_lookup_reference (GgitRepository  *repository,
 
 	if (ret == GIT_OK)
 	{
-		if (g_str_has_prefix (name, "refs/heads/"))
-		{
-			ref = GGIT_REF (_ggit_branch_wrap (reference));
-		}
-		else
-		{
-			ref = _ggit_ref_wrap (reference);
-		}
+		ref = _ggit_ref_wrap (reference);
 	}
 	else
 	{
@@ -1687,7 +1744,7 @@ ggit_repository_lookup_branch (GgitRepository *repository,
 }
 
 /**
- * ggit_repository_get_remote:
+ * ggit_repository_lookup_remote:
  * @repository: a #GgitRepository.
  * @name: the remote's name.
  * @error: a #GError for error reporting, or %NULL.
@@ -1697,9 +1754,9 @@ ggit_repository_lookup_branch (GgitRepository *repository,
  * Returns: (transfer full) (allow-none): a new #GgitRemote or %NULL if there is an error.
  */
 GgitRemote *
-ggit_repository_get_remote (GgitRepository  *repository,
-                            const gchar     *name,
-                            GError         **error)
+ggit_repository_lookup_remote (GgitRepository  *repository,
+                               const gchar     *name,
+                               GError         **error)
 {
 	gint ret;
 	git_remote *remote;
@@ -1708,7 +1765,7 @@ ggit_repository_get_remote (GgitRepository  *repository,
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	ret = git_remote_load (&remote,
+	ret = git_remote_lookup (&remote,
 	                       _ggit_native_get (repository),
 	                       name);
 
@@ -1909,6 +1966,7 @@ ggit_repository_submodule_foreach (GgitRepository        *repository,
  * @repository: a #GgitRepository.
  * @target: the target #GgitObject which is a commit or a tag.
  * @reset_type: the #GgitResetType to perform.
+ * @checkout_options: the #GgitCheckoutOptions to be used for a HARD reset.
  * @signature: a #GgitSignature that will used to populate the reflog entry.
  * @log_message: The one line long message to be appended to the reflog.
  * @error: a #GError for error reporting, or %NULL.
@@ -1917,17 +1975,19 @@ ggit_repository_submodule_foreach (GgitRepository        *repository,
  * or @error will be set.
  */
 void
-ggit_repository_reset (GgitRepository  *repository,
-                       GgitObject      *target,
-                       GgitResetType    reset_type,
-                       GgitSignature   *signature,
-                       const gchar     *log_message,
-                       GError         **error)
+ggit_repository_reset (GgitRepository       *repository,
+                       GgitObject           *target,
+                       GgitResetType         reset_type,
+                       GgitCheckoutOptions  *checkout_options,
+                       GgitSignature        *signature,
+                       const gchar          *log_message,
+                       GError              **error)
 {
 	gint ret;
 
 	g_return_if_fail (GGIT_IS_REPOSITORY (repository));
 	g_return_if_fail (GGIT_IS_OBJECT (target));
+	g_return_if_fail (GGIT_IS_CHECKOUT_OPTIONS (checkout_options));
 	g_return_if_fail (GGIT_IS_SIGNATURE (signature));
 	g_return_if_fail (log_message != NULL);
 	g_return_if_fail (error == NULL || *error == NULL);
@@ -1935,6 +1995,7 @@ ggit_repository_reset (GgitRepository  *repository,
 	ret = git_reset (_ggit_native_get (repository),
 	                 _ggit_native_get (target),
 	                 (git_reset_t)reset_type,
+	                 (git_checkout_options *)_ggit_checkout_options_get_checkout_options (checkout_options),
 	                 _ggit_native_get (signature),
 	                 log_message);
 
@@ -1948,7 +2009,7 @@ ggit_repository_reset (GgitRepository  *repository,
  * ggit_repository_reset_default:
  * @repository: a #GgitRepository.
  * @target: (allow-none): the target #GgitObject which is a commit or a tag.
- * @pathspecs: a list of file paths to reset.
+ * @pathspecs: (array zero-terminated=1): a list of file paths to reset.
  * @error: a #GError for error reporting or %NULL.
  *
  * Update some entries in the index from the target commit tree. The scope of
@@ -2490,20 +2551,31 @@ ggit_repository_create_commit_from_ids (GgitRepository  *repository,
 /**
  * ggit_repository_create_tree_builder:
  * @repository: a #GgitRepository.
+ * @error: a #GError for error reporting, or %NULL.
  *
  * Create a new tree builder.
  *
- * Returns: (transfer full): a #GgitTreeBuilder.
- *
+ * Returns: (transfer full): a new #GgitTreeBuilder, or %NULL if there was an error.
  **/
 GgitTreeBuilder *
-ggit_repository_create_tree_builder (GgitRepository *repository)
+ggit_repository_create_tree_builder (GgitRepository  *repository,
+                                     GError         **error)
 {
+	gint ret;
 	git_treebuilder *builder;
 
 	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
 
-	git_treebuilder_create (&builder, NULL);
+	ret = git_treebuilder_new (&builder,
+	                           _ggit_native_get (repository),
+	                           NULL);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
 	return _ggit_tree_builder_wrap (builder, repository, TRUE);
 }
 
@@ -2516,7 +2588,6 @@ ggit_repository_create_tree_builder (GgitRepository *repository)
  * tree builder, use #ggit_repository_create_tree_builder instead.
  *
  * Returns: (transfer full): a new #GgitTreeBuilder object, or %NULL if there was an error.
- *
  **/
 GgitTreeBuilder *
 ggit_repository_create_tree_builder_from_tree (GgitRepository  *repository,
@@ -2530,7 +2601,9 @@ ggit_repository_create_tree_builder_from_tree (GgitRepository  *repository,
 	g_return_val_if_fail (GGIT_IS_TREE (tree), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	ret = git_treebuilder_create (&builder, _ggit_native_get (tree));
+	ret = git_treebuilder_new (&builder,
+	                           _ggit_native_get (repository),
+	                           _ggit_native_get (tree));
 
 	if (ret != GIT_OK)
 	{
@@ -2932,9 +3005,9 @@ ggit_repository_cherry_pick (GgitRepository         *repository,
 	g_return_val_if_fail (options == NULL || GGIT_IS_CHERRY_PICK_OPTIONS (options), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	ret = git_cherry_pick (_ggit_native_get (repository),
-	                       _ggit_native_get (commit),
-	                       _ggit_cherry_pick_options_get_cherry_pick_options (options));
+	ret = git_cherrypick (_ggit_native_get (repository),
+	                      _ggit_native_get (commit),
+	                      _ggit_cherry_pick_options_get_cherry_pick_options (options));
 
 	if (ret != GIT_OK)
 	{
@@ -2976,12 +3049,12 @@ ggit_repository_cherry_pick_commit (GgitRepository    *repository,
 	g_return_val_if_fail (GGIT_IS_COMMIT (our_commit), NULL);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	ret = git_cherry_pick_commit (&idx,
-	                              _ggit_native_get (repository),
-	                              _ggit_native_get (commit),
-	                              _ggit_native_get (our_commit),
-	                              mainline,
-	                              _ggit_merge_options_get_merge_options (merge_options));
+	ret = git_cherrypick_commit (&idx,
+	                             _ggit_native_get (repository),
+	                             _ggit_native_get (commit),
+	                             _ggit_native_get (our_commit),
+	                             mainline,
+	                             _ggit_merge_options_get_merge_options (merge_options));
 
 	if (ret != GIT_OK)
 	{
@@ -3026,9 +3099,9 @@ ggit_repository_get_default_notes_ref (GgitRepository  *repository,
 /**
  * ggit_repository_create_note:
  * @repository: a #GgitRepository.
+ * @notes_ref: (allow-none): canonical name of the reference to use, or %NULL to use the default ref.
  * @author: author signature.
  * @committer: committer signature.
- * @notes_ref: (allow-none): canonical name of the reference to use, or %NULL to use the default ref.
  * @id: OID of the git object to decorate.
  * @note: content of the note to add for object oid.
  * @force: whether to overwrite existing note.
@@ -3040,9 +3113,9 @@ ggit_repository_get_default_notes_ref (GgitRepository  *repository,
  */
 GgitOId *
 ggit_repository_create_note (GgitRepository  *repository,
+                             const gchar     *notes_ref,
                              GgitSignature   *author,
                              GgitSignature   *committer,
-                             const gchar     *notes_ref,
                              GgitOId         *id,
                              const gchar     *note,
                              gboolean         force,
@@ -3060,9 +3133,9 @@ ggit_repository_create_note (GgitRepository  *repository,
 
 	ret = git_note_create (&oid,
 	                       _ggit_native_get (repository),
+	                       notes_ref,
 	                       _ggit_native_get (author),
 	                       _ggit_native_get (committer),
-	                       notes_ref,
 	                       _ggit_oid_get_oid (id),
 	                       note,
 	                       force);
