@@ -105,7 +105,7 @@ ASSERT_ENUM (GGIT_ERROR_BUFS,        GIT_EBUFS);
 ASSERT_ENUM (GGIT_ERROR_PASSTHROUGH, GIT_PASSTHROUGH);
 ASSERT_ENUM (GGIT_ERROR_ITEROVER,    GIT_ITEROVER);
 
-ASSERT_ENUM (GGIT_FILE_MODE_NEW, GIT_FILEMODE_NEW);
+ASSERT_ENUM (GGIT_FILE_MODE_UNREADABLE, GIT_FILEMODE_UNREADABLE);
 ASSERT_ENUM (GGIT_FILE_MODE_TREE, GIT_FILEMODE_TREE);
 ASSERT_ENUM (GGIT_FILE_MODE_BLOB, GIT_FILEMODE_BLOB);
 ASSERT_ENUM (GGIT_FILE_MODE_BLOB_EXECUTABLE, GIT_FILEMODE_BLOB_EXECUTABLE);
@@ -265,4 +265,13 @@ ASSERT_ENUM (GGIT_DIFF_FIND_REMOVE_UNMODIFIED,          GIT_DIFF_FIND_REMOVE_UNM
 ASSERT_ENUM (GGIT_DIFF_FORMAT_EMAIL_NONE, GIT_DIFF_FORMAT_EMAIL_NONE);
 ASSERT_ENUM (GGIT_DIFF_FORMAT_EMAIL_EXCLUDE_SUBJECT_PATCH_MARKER, GIT_DIFF_FORMAT_EMAIL_EXCLUDE_SUBJECT_PATCH_MARKER);
 
+ASSERT_ENUM (GGIT_CREDTYPE_USERPASS_PLAINTEXT, GIT_CREDTYPE_USERPASS_PLAINTEXT);
+ASSERT_ENUM (GGIT_CREDTYPE_SSH_KEY, GIT_CREDTYPE_SSH_KEY);
+ASSERT_ENUM (GGIT_CREDTYPE_SSH_CUSTOM, GIT_CREDTYPE_SSH_CUSTOM);
+ASSERT_ENUM (GGIT_CREDTYPE_DEFAULT, GIT_CREDTYPE_DEFAULT);
+ASSERT_ENUM (GGIT_CREDTYPE_SSH_INTERACTIVE, GIT_CREDTYPE_SSH_INTERACTIVE);
+
+ASSERT_ENUM (GGIT_DIRECTION_FETCH, GIT_DIRECTION_FETCH);
+ASSERT_ENUM (GGIT_DIRECTION_PUSH, GIT_DIRECTION_PUSH);
+
 /* ex:set ts=8 noet: */
