@@ -285,11 +285,11 @@ typedef struct _GgitOId GgitOId;
 typedef struct _GgitPatch GgitPatch;
 
 /**
- * GgitPush:
+ * GgitPushOptions:
  *
- * Represents a git push.
+ * Represents a git push options.
  */
-typedef struct _GgitPush GgitPush;
+typedef struct _GgitPushOptions GgitPushOptions;
 
 /**
  * GgitRef:
@@ -376,6 +376,13 @@ typedef struct _GgitStatusOptions GgitStatusOptions;
  */
 typedef struct _GgitSubmodule GgitSubmodule;
 
+/**
+ * GgitSubmoduleUpdateOptions:
+ *
+ * Represents options for a submodule update.
+ */
+typedef struct _GgitSubmoduleUpdateOptions GgitSubmoduleUpdateOptions;
+
 /**
  * GgitTag:
  *
@@ -686,7 +693,7 @@ typedef enum {
 
 /* NOTE: keep in sync with git2/refs.h */
 typedef enum {
-	GGIT_FILE_MODE_NEW             = 0000000,
+	GGIT_FILE_MODE_UNREADABLE      = 0000000,
 	GGIT_FILE_MODE_TREE            = 0040000,
 	GGIT_FILE_MODE_BLOB            = 0100644,
 	GGIT_FILE_MODE_BLOB_EXECUTABLE = 0100755,
@@ -963,9 +970,7 @@ typedef enum {
 	GGIT_STATUS_OPTION_RENAMES_INDEX_TO_WORKDIR = (1 << 8),
 	GGIT_STATUS_OPTION_SORT_CASE_SENSITIVELY    = (1 << 9),
 	GGIT_STATUS_OPTION_SORT_CASE_INSENSITIVELY  = (1 << 10),
-	GGIT_STATUS_OPTION_DEFAULT                  = GGIT_STATUS_OPTION_INCLUDE_IGNORED |
-	                                              GGIT_STATUS_OPTION_INCLUDE_UNTRACKED |
-	                                              GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS
+	GGIT_STATUS_OPTION_DEFAULT                  = GGIT_STATUS_OPTION_INCLUDE_IGNORED | GGIT_STATUS_OPTION_INCLUDE_UNTRACKED | GGIT_STATUS_OPTION_RECURSE_UNTRACKED_DIRS
 } GgitStatusOption;
 
 /**
@@ -1077,6 +1082,21 @@ typedef enum
 	GGIT_DIFF_FORMAT_EMAIL_EXCLUDE_SUBJECT_PATCH_MARKER = (1 << 0)
 } GgitDiffFormatEmailFlags;
 
+typedef enum
+{
+	GGIT_CREDTYPE_USERPASS_PLAINTEXT = (1u << 0),
+	GGIT_CREDTYPE_SSH_KEY            = (1u << 1),
+	GGIT_CREDTYPE_SSH_CUSTOM         = (1u << 2),
+	GGIT_CREDTYPE_DEFAULT            = (1u << 3),
+	GGIT_CREDTYPE_SSH_INTERACTIVE    = (1u << 4),
+} GgitCredtype;
+
+typedef enum
+{
+	GGIT_DIRECTION_FETCH = 0,
+	GGIT_DIRECTION_PUSH  = 1
+} GgitDirection;
+
 /**
  * GgitConfigCallback:
  * @entry: a #GgitConfigEntry.
